@@ -24,7 +24,7 @@ import re
 
 
 __all__ = ['color', 'uncolor', 'colored', 'colorstrip', 'colorvalid']
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 _ATTRIBUTES = {
@@ -101,7 +101,8 @@ def color(*attrs):
         try:
             codes.append(_ATTRIBUTES[attr])
         except KeyError:
-            raise ValueError('invalid attribute name: {!r}'.format(attr))
+            raise ValueError('invalid attribute name: {!r}'.format(attr)) \
+                    from None
     if not codes:
         return ''
     codes = ';'.join(map(str, codes))
@@ -129,7 +130,8 @@ def uncolor(*escapes):
         try:
             attr = _ATTRIBUTES_R[code]
         except KeyError:
-            raise ValueError('no name for escape sequence {!r}'.format(code))
+            raise ValueError('no name for escape sequence {!r}'.format(code)) \
+                    from None
         attrs.append(attr)
     return attrs
 
